activatePackage(Doors);


package Doors {

function OpenDoor(%Door, %Time, %Frames, %MoveX, %MoveY, %MoveZ)
{
   //Takes an object and moves it over the time specified in ms, using a specified number of frames
   //
   //Proper usage: 
   //
   // OpenDoor(<ObjectToBeMoved>, <TimeInMS>, <#OfFramesToUse>, <XOffset>, <YOffset>, <ZOffset> );   
   //
   // So:
   // OpenDoor(NameToID("TheDoor"), 3000, 100, 10, 0, 0 );
   //                Moves "TheDoor" 10m in the x direction over 3 seconds and uses 100 frames
   //
   // Note: best used with small objects, if frames is <= 0, it will be set to 30 fps
   //
   // Note that frames should be large enough to look smooth, and small enough not to eat up to much proccessing time:  
   //  100 is a generally good setting, but play with it as desired
   //
   // Thanx to Dev for the Waterlevel script, this is based off that :)

  if(!isObject(%Door)) //If it isnt an object, error
  {
    echo("Unable to set movement on non-object classes, First parameter invalid");
    return;
  }
    echo("Moving Object...");

   if(%Frames <= 0)
   {
     %Frames = 30 * %Time / 1000;
   }


   // Loop through and schedule the moving of the door now.   
   %i = 1;
   %deltaX = %MoveX / %Frames;
   %deltaY = %MoveY / %Frames;
   %deltaZ = %MoveZ / %Frames;

   while (%i <= %Frames)
   {
      Schedule(%i  / %Frames * %Time, 0, MoveDoor, %Door, %deltaX, %deltaY, %deltaZ);
   
      %i++;   
   }
    //echo("after scheduling, i: " @ %i );
}

//actually does the move

function MoveDoor(%Door, %ChangeX, %ChangeY, %ChangeZ)
{
   %MoveX = getWord(%Door.Position, 0) + %ChangeX;
   %MoveY = getWord(%Door.Position, 1) + %ChangeY;
   %MoveZ = getWord(%Door.Position, 2) + %ChangeZ;

   %Door.Position = %MoveX @ " " @ %MoveY @ " " @ %MoveZ;
   //echo("Door position: " @ %Door.position );
   // Just needed to cause a refresh
   %rot = rotFromTransform(%Door.getTransform());

   %Door.setTransForm(%Door.Position SPC %rot);

}

};//end package doors